/**************************************************************************
   Copyright (C) 1994 by R.Harmsen.
 *************************************************************************/

#ifndef TIMERCHP_H
#define TIMERCHP_H

typedef void interrupt time_handler (...);


/********************************************************************
   The timer will be adjusted to it calls the new_time_handler
   rate times a second. Note that in the the new_time_handler,
   you must still call the original 18.2 times a second.

   For example, this can be done as follows:
   (because handlers are often time-critical, this is not provided
    as a function here).
   Here call_ratio is how much faster than 18.2
   the rate has been made. The orig_time_handler is returned by
   function set_timer_interrupt.


   if (--r_cnt <= 0)
   {
      orig_time_handler();
      r_cnt = call_ratio;
   }
   else
   {
      // Tell the 8259 interrupt handler, that this one has been handled,
      // so new interrupts may be accepted (the original handler does
      // this automatically, so if called this need not be done.
      outportb(0x20, 0x20);
   }
 *******************************************************************/
time_handler *set_timer_interrupt
   (long rate, time_handler *new_time_handler);

/********************************************************************
   Change the timer rate on second thoughts.

   Returns perhaps slightly modified rate.
 *******************************************************************/
long set_timer_speed (long rate);


/********************************************************************
   Distach own handlers from the timer, resetting its original
   speed.
 *******************************************************************/
void reset_timer_interrupt (void);

#endif
